@@ -15,7 +15,7 @@
 #'
 #' \item a two element vector containing an isotopic ratio and its standard
 #' error, or the spontaneous and induced track densities \code{Ns} and
-#' \code{Ni} (if \code{method='fissiontracks'}),
+#' \code{Ni},
 #'
 #' \item a four element vector containing \code{Ar40Ar39},
 #' \code{s[Ar40Ar39]}, \code{J}, \code{s[J]},
@@ -54,15 +54,15 @@
 #' \code{ReOs}, \code{LuHf}, \code{UThHe} or \code{fissiontracks}.  }
 #'
 #' @param method one of either \code{'U238-Pb206'},
-#'     \code{'U235-Pb207'}, \code{'Pb207-Pb206'}, \code{'Ar-Ar'},
-#'     \code{'K-Ca'}, \code{'Th-U'}, \code{'Re-Os'}, \code{'Sm-Nd'},
-#'     \code{'Rb-Sr'}, \code{'Lu-Hf'}, \code{'U-Th-He'} or
-#'     \code{'fissiontracks'}
+#'     \code{'U235-Pb207'}, \code{'Pb207-Pb206'},
+#'     \code{'Th232-Pb208'}, \code{'Ar-Ar'}, \code{'K-Ca'},
+#'     \code{'Th-U'}, \code{'Re-Os'}, \code{'Sm-Nd'}, \code{'Rb-Sr'},
+#'     \code{'Lu-Hf'}, \code{'U-Th-He'} or \code{'fissiontracks'}
 #' 
 #' @param exterr propagate the external (decay constant and
 #'     calibration factor) uncertainties?
 #' 
-#' @param i (optional) index of a particular aliquot
+#' @param i index of a particular aliquot
 #' 
 #' @param d an object of class \code{\link{diseq}}.
 #' 
@@ -82,7 +82,7 @@ age.default <- function(x,method='U238-Pb206',exterr=TRUE,J=c(NA,NA),
         out <- get.Pb206U238.age(x=x[1],sx=x[2],exterr=exterr,d=d)
     } else if (identical(method,'Pb207-Pb206')){
         out <- get.Pb207Pb206.age(x=x[1],sx=x[2],exterr,d=d)
-    } else if (identical(method,'Pb208-Th238')){
+    } else if (identical(method,'Th232-Pb208')){
         out <- get.Pb208Th232.age(x=x[1],sx=x[2],exterr,d=d)
     } else if (identical(method,'Ar-Ar')){
         out <- get.ArAr.age(Ar40Ar39=x[1],sAr40Ar39=x[2],
@@ -140,14 +140,24 @@ age.default <- function(x,method='U238-Pb206',exterr=TRUE,J=c(NA,NA),
 #' @param common.Pb apply a common lead correction using one of three
 #'     methods:
 #'
-#' \code{1}: use the Stacey-Kramer two-stage model to infer the initial
+#' \code{1}: the Stacey-Kramer two-stage model to infer the initial
 #' Pb-composition
 #'
-#' \code{2}: use the isochron intercept as the initial Pb-composition
+#' \code{2}: the isochron intercept as the initial Pb-composition
 #'
-#' \code{3}: use the Pb-composition stored in
+#' \code{3}: the Pb-composition stored in
+#' 
+#' \code{settings('iratio','Pb206Pb204')} (if \code{x} has class
+#' \code{UPb} and \code{x$format<4});
+#' 
 #' \code{settings('iratio','Pb206Pb204')} and
-#' \code{settings('iratio','Pb207Pb204')}
+#' \code{settings('iratio','Pb207Pb204')} (if \code{x} has class
+#' \code{PbPb} or \code{x} has class \code{UPb} and
+#' \code{3<x$format<7}); or
+#'
+#' \code{settings('iratio','Pb208Pb206')} and
+#' \code{settings('iratio','Pb208Pb207')} (if \code{x} has class
+#' \code{UPb} and \code{x$format=7} or \code{8}).
 #' 
 #' @param show.p Show the p-value for concordance for each aliquot to
 #'     the output table. Note: it would be unwise to use the p-value
@@ -254,13 +264,13 @@ age.PbPb <- function(x,isochron=TRUE,common.Pb=1,
 #' @param i2i `isochron to intercept': calculates the initial (aka
 #'     `inherited', `excess', or `common')
 #'     \eqn{^{40}}Ar/\eqn{^{36}}Ar, \eqn{^{40}}Ca/\eqn{^{44}}Ca,
-#'     \eqn{^{207}}Pb/\eqn{^{204}}Pb, \eqn{^{87}}Sr/\eqn{^{86}}Sr,
-#'     \eqn{^{143}}Nd/\eqn{^{144}}Nd, \eqn{^{187}}Os/\eqn{^{188}}Os or
-#'     \eqn{^{176}}Hf/\eqn{^{177}}Hf ratio from an isochron
-#'     fit. Setting \code{i2i} to \code{FALSE} uses the default values
-#'     stored in \code{settings('iratio',...)}. When applied to data
-#'     of class \code{ThU}, setting \code{i2i} to \code{TRUE} applies
-#'     a detrital Th-correction.
+#'     \eqn{^{87}}Sr/\eqn{^{86}}Sr, \eqn{^{143}}Nd/\eqn{^{144}}Nd,
+#'     \eqn{^{187}}Os/\eqn{^{188}}Os or \eqn{^{176}}Hf/\eqn{^{177}}Hf
+#'     ratio from an isochron fit. Setting \code{i2i} to \code{FALSE}
+#'     uses the default values stored in
+#'     \code{settings('iratio',...)}. When applied to data of class
+#'     \code{ThU}, setting \code{i2i} to \code{TRUE} applies a
+#'     detrital Th-correction.
 #'
 #' @rdname age
 #' @export
@@ -357,18 +367,18 @@ add.exterr <- function(x,tt,st,cutoff.76=1100,type=4){
     out <- c(tt,st)
     if (hasClass(x,'UPb')){
         if (type==1){
-            R <- age_to_Pb207U235_ratio(tt,st)
-            out <- get.Pb207U235.age(R[,1],R[,2],exterr=TRUE)
+            R <- age_to_Pb207U235_ratio(tt,st,d=x$d)
+            out <- get.Pb207U235.age(R[1],R[2],d=x$d,exterr=TRUE)
         } else if (type==2 | (type==4 & (tt<cutoff.76)) | (type==5)){
-            R <- age_to_Pb206U238_ratio(tt,st)
-            out <- get.Pb206U238.age(R[,1],R[,2],exterr=TRUE)
+            R <- age_to_Pb206U238_ratio(tt,st,d=x$d)
+            out <- get.Pb206U238.age(R[1],R[2],d=x$d,exterr=TRUE)
         } else if (type==3 | (type==4 & (tt>=cutoff.76))){
-            R <- age_to_Pb207Pb206_ratio(tt,st)
-            out <- get.Pb207Pb206.age(R[,1],R[,2],exterr=TRUE)
+            R <- age_to_Pb207Pb206_ratio(tt,st,d=x$d)
+            out <- get.Pb207Pb206.age(R[1],R[2],d=x$d,exterr=TRUE)
         }
     } else if (hasClass(x,'PbPb')){
         R <- age_to_Pb207Pb206_ratio(tt,st)
-        out <- get.Pb207Pb206.age(R[,1],R[,2],exterr=TRUE)
+        out <- get.Pb207Pb206.age(R[1],R[2],exterr=TRUE)
     } else if (hasClass(x,'ArAr')){
         R <- get.ArAr.ratio(tt,st,x$J[1],0,exterr=FALSE)
         out <- get.ArAr.age(R[1],R[2],x$J[1],x$J[2],exterr=TRUE)
@@ -387,7 +397,7 @@ add.exterr <- function(x,tt,st,cutoff.76=1100,type=4){
     } else if (hasClass(x,'LuHf')){
         R <- get.LuHf.ratio(tt,st,exterr=FALSE)
         out <- get.LuHf.age(R[1],R[2],exterr=TRUE)
-    } else if (hasClass(x,'fissiontracks')){
+    } else if (hasClass(x,'fissiontracks') & x$format<3){
         out[2] <- tt * sqrt( (x$zeta[2]/x$zeta[1])^2 + (st/tt)^2 )
     }
     out
