@@ -58,26 +58,21 @@
 #'     either be a single colour or multiple colours to form a colour
 #'     ramp (to be used if \code{levels!=NA}):
 #'
-#' \itemize{
+#' a single colour: \code{rgb(0,1,0,0.5)}, \code{'#FF000080'},
+#' \code{'white'}, etc.;
 #'
-#' \item{a single colour: \code{rgb(0,1,0,0.5)}, \code{'#FF000080'},
-#' \code{'white'}, etc.}
-#'
-#' \item{multiple colours: \code{c(rbg(1,0,0,0.5)},
+#' multiple colours: \code{c(rbg(1,0,0,0.5)},
 #' \code{rgb(0,1,0,0.5))}, \code{c('#FF000080','#00FF0080')},
-#' \code{c('blue','red')}, \code{c('blue','yellow','red')}, etc.}
+#' \code{c('blue','red')}, \code{c('blue','yellow','red')}, etc.;
 #'
-#' \item{a colour palette: \code{rainbow(n=100)},
-#' \code{topo.colors(n=100,alpha=0.5)}, etc.}
+#' a colour palette: \code{rainbow(n=100)},
+#' \code{topo.colors(n=100,alpha=0.5)}, etc.; or
 #'
-#' \item{a reversed palette: \code{rev(topo.colors(n=100,alpha=0.5))},
-#' etc.}
+#' a reversed palette: \code{rev(topo.colors(n=100,alpha=0.5))}, etc.
 #'
-#' \item{for plot symbols, set \code{bg=NA}}
+#' for plot symbols, set \code{bg=NA}
 #'
-#' }
 #' @param col text colour to be used if \code{show.numbers=TRUE}
-#' @param title add a title to the plot?
 #' @param k number of peaks to fit using the finite mixture models of
 #'     Galbraith and Laslett (1993). Setting \code{k='auto'}
 #'     automatically selects an optimal number of components based on
@@ -125,33 +120,28 @@ radialplot.default <- function(x,from=NA,to=NA,t0=NA,
                                transformation='log',sigdig=2,
                                show.numbers=FALSE,pch=21,levels=NA,
                                clabel="",bg=c("yellow","red"),col='black',
-                               title=TRUE,k=0,markers=NULL,alpha=0.05,
+                               k=0,markers=NULL,alpha=0.05,
                                units='',hide=NA,omit=NA,omit.col=NA,...){
-    x <- x[,c(1,2)]
+    x <- x[,c(1,2),drop=FALSE]
     ns <- nrow(x)
     calcit <- (1:ns)%ni%c(hide,omit)
-    plotit <- (1:ns)%ni%hide
     x2calc <- clear(x,hide,omit)
-    x2plot <- clear(x,hide)
     peaks <- peakfit(x2calc,k=k,sigdig=sigdig)
     markers <- c(markers,peaks$peaks['t',])
-    X <- x2zs(x2plot,t0=t0,from=from,to=to,transformation=transformation)
-    pcol <- set.ellipse.colours(ns=ns,levels=levels,col=bg,hide=hide,
-                                omit=omit,omit.col=omit.col)
-    tcol <- rep(col,ns)
-    tcol[omit] <- 'grey'
-    radial.plot(X,show.numbers=show.numbers,pch=pch,
-                levels=levels[plotit],clabel=clabel,markers=markers,
-                bg=pcol[plotit],col=tcol[plotit],sn=(1:ns)[plotit],...)
-    colourbar(z=levels[calcit],col=bg,clabel=clabel)
-    if (title)
-        title(radial.title(x2calc,sigdig=sigdig,alpha=alpha,
-                           units=units,ntit=get.ntit(x2calc[,1])))
+    radial_helper(x,from=from,to=to,t0=t0,
+                  transformation=transformation,
+                  show.numbers=show.numbers,pch=pch,levels=levels,
+                  clabel=clabel,bg=bg,col=col,markers=markers,
+                  alpha=alpha,units=units,hide=hide,omit=omit,
+                  omit.col=omit.col,...)
+    fit <- central(x,alpha=alpha)
+    graphics::title(radial.title(fit,sigdig=sigdig,alpha=alpha,
+                                 units=units,ntit=get.ntit(x2calc[,1])))
     if (!is.null(peaks$legend))
         graphics::legend('bottomleft',legend=peaks$legend,bty='n')
 }
-#' @param exterr propagate the external sources of uncertainty into
-#'     the mixture model errors?
+#' @param exterr include the external sources of uncertainty into
+#'     the error propagation for the central age and mixture models?
 #' @rdname radialplot
 #' @export
 radialplot.fissiontracks <- function(x,from=NA,to=NA,t0=NA,
@@ -159,9 +149,8 @@ radialplot.fissiontracks <- function(x,from=NA,to=NA,t0=NA,
                                      show.numbers=FALSE,pch=21,
                                      levels=NA,clabel="",
                                      bg=c("yellow","red"),col='black',
-                                     title=TRUE,markers=NULL,k=0,
-                                     exterr=TRUE,alpha=0.05,hide=NULL,
-                                     omit=NULL,omit.col=NA,...){
+                                     markers=NULL,k=0,exterr=TRUE,alpha=0.05,
+                                     hide=NULL,omit=NULL,omit.col=NA,...){
     ns <- length(x)
     calcit <- (1:ns)%ni%c(hide,omit)
     plotit <- (1:ns)%ni%hide
@@ -181,19 +170,19 @@ radialplot.fissiontracks <- function(x,from=NA,to=NA,t0=NA,
                 markers=markers,bg=pcol[plotit],
                 col=tcol[plotit],sn=(1:ns)[plotit],...)
     colourbar(z=levels[calcit],col=bg,clabel=clabel)
-    if (title)
-        title(radial.title(x2calc,sigdig=sigdig,alpha=alpha,
-                           units='Ma',ntit=get.ntit(x2calc$x[,1])))
+    fit <- central(x2calc,alpha=alpha,exterr=exterr)
+    graphics::title(radial.title(fit,sigdig=sigdig,alpha=alpha,
+                                 units='Ma',ntit=get.ntit(x2calc)))
     if (!is.null(peaks$legend))
         graphics::legend('bottomleft',legend=peaks$legend,bty='n')
 }
 #' @param type scalar indicating whether to plot the
 #'     \eqn{^{207}}Pb/\eqn{^{235}}U age (\code{type}=1), the
 #'     \eqn{^{206}}Pb/\eqn{^{238}}U age (\code{type}=2), the
-#'     \eqn{^{207}}Pb/\eqn{^{206}}Pb age (type=3), the
+#'     \eqn{^{207}}Pb/\eqn{^{206}}Pb age (\code{type}=3), the
 #'     \eqn{^{207}}Pb/\eqn{^{206}}Pb-\eqn{^{206}}Pb/\eqn{^{238}}U age
-#'     (\code{type}=4), or the (Wetherill) concordia age
-#'     (\code{type}=5)
+#'     (\code{type}=4), the concordia age (\code{type}=5), or the
+#'     \eqn{^{208}}Pb/\eqn{^{232}}Th age (\code{type}=6).
 #' @param cutoff.76 the age (in Ma) below which the
 #'     \eqn{^{206}}Pb/\eqn{^{238}}U and above which the
 #'     \eqn{^{207}}Pb/\eqn{^{206}}Pb age is used. This parameter is
@@ -213,35 +202,46 @@ radialplot.fissiontracks <- function(x,from=NA,to=NA,t0=NA,
 #' (\code{FALSE}) the common-Pb correction.
 #'
 #' Set \code{cutoff.disc=NA} to turn off this filter.
+#'
 #' @param common.Pb apply a common lead correction using one of three
 #'     methods:
 #'
-#' \code{1}: use the isochron intercept as the initial Pb-composition
-#'
-#' \code{2}: use the Stacey-Kramers two-stage model to infer the initial
+#' \code{1}: the Stacey-Kramer two-stage model to infer the initial
 #' Pb-composition
 #'
-#' \code{3}: use the Pb-composition stored in
+#' \code{2}: the isochron intercept as the initial Pb-composition
+#'
+#' \code{3}: the Pb-composition stored in
+#' 
+#' \code{settings('iratio','Pb206Pb204')} (if \code{x} has class
+#' \code{UPb} and \code{x$format<4});
+#' 
 #' \code{settings('iratio','Pb206Pb204')} and
-#' \code{settings('iratio','Pb207Pb204')}
+#' \code{settings('iratio','Pb207Pb204')} (if \code{x} has class
+#' \code{PbPb} or \code{x} has class \code{UPb} and
+#' \code{3<x$format<7}); or
+#'
+#' \code{settings('iratio','Pb208Pb206')} and
+#' \code{settings('iratio','Pb208Pb207')} (if \code{x} has class
+#' \code{UPb} and \code{x$format=7} or \code{8}).
 #'
 #' @rdname radialplot
 #' @export
 radialplot.UPb <- function(x,from=NA,to=NA,t0=NA,
                            transformation='log',type=4,
                            cutoff.76=1100,cutoff.disc=list(-15,5,TRUE),
-                           show.numbers=FALSE,pch=21,
+                           show.numbers=FALSE,pch=21,sigdig=2,
                            levels=NA,clabel="",bg=c("yellow","red"),
                            col='black',markers=NULL,k=0,exterr=TRUE,
                            common.Pb=0,alpha=0.05,hide=NULL,
                            omit=NULL,omit.col=NA,...){
-    radialplot_helper(x,from=from,to=to,t0=t0,
-                      transformation=transformation,type=type,
-                      cutoff.76=cutoff.76,cutoff.disc=cutoff.disc,
-                      show.numbers=show.numbers,pch=pch,levels=levels,
-                      clabel=clabel,bg=bg,col=col,markers=markers,
-                      k=k,exterr=exterr,alpha=alpha,hide=hide,
-                      omit=omit,omit.col=omit.col,common.Pb=common.Pb,...)
+    age2radial(x,from=from,to=to,t0=t0,sigdig=sigdig,
+               transformation=transformation,type=type,
+               cutoff.76=cutoff.76,cutoff.disc=cutoff.disc,
+               show.numbers=show.numbers,pch=pch,levels=levels,
+               clabel=clabel,bg=bg,col=col,markers=markers,
+               k=k,exterr=exterr,alpha=alpha,hide=hide,
+               omit=omit,omit.col=omit.col,common.Pb=common.Pb,...)
 }
 #' @param i2i `isochron to intercept': calculates the initial (aka
 #'     `inherited', `excess', or `common')
@@ -254,129 +254,129 @@ radialplot.UPb <- function(x,from=NA,to=NA,t0=NA,
 #'     \code{settings('iratio',...)}.
 #' @rdname radialplot
 #' @export
-radialplot.PbPb <- function(x,from=NA,to=NA,t0=NA,
+radialplot.PbPb <- function(x,from=NA,to=NA,t0=NA,sigdig=2,
                             transformation='log',show.numbers=FALSE,
                             pch=21,levels=NA,clabel="",bg=c("yellow","red"),
                             col='black',markers=NULL,k=0,
                             exterr=TRUE,common.Pb=1,alpha=0.05,
                             hide=NULL,omit=NULL,omit.col=NA,...){
-    radialplot_helper(x,from=from,to=to,t0=t0,
-                      transformation=transformation,
-                      show.numbers=show.numbers,pch=pch,levels=levels,
-                      clabel=clabel,bg=bg,col=col,markers=markers,k=k,
-                      exterr=exterr,alpha=alpha,hide=hide,omit=omit,
-                      omit.col=omit.col,common.Pb=common.Pb,...)
+    age2radial(x,from=from,to=to,t0=t0,sigdig=sigdig,
+               transformation=transformation,
+               show.numbers=show.numbers,pch=pch,levels=levels,
+               clabel=clabel,bg=bg,col=col,markers=markers,k=k,
+               exterr=exterr,alpha=alpha,hide=hide,omit=omit,
+               omit.col=omit.col,common.Pb=common.Pb,...)
 }
 #' @rdname radialplot
 #' @export
-radialplot.ArAr <- function(x,from=NA,to=NA,t0=NA,
+radialplot.ArAr <- function(x,from=NA,to=NA,t0=NA,sigdig=2,
                             transformation='log',show.numbers=FALSE,
                             pch=21,levels=NA,clabel="",
                             bg=c("yellow","red"),col='black',
                             markers=NULL,k=0,exterr=TRUE,i2i=FALSE,
                             alpha=0.05,hide=NULL,omit=NULL,
                             omit.col=NA,...){
-    radialplot_helper(x,from=from,to=to,t0=t0,
-                      transformation=transformation,
-                      show.numbers=show.numbers,pch=pch,levels=levels,
-                      clabel=clabel,bg=bg,col=col,markers=markers,k=k,
-                      exterr=exterr,i2i=i2i,alpha=alpha,hide=hide,
-                      omit=omit,omit.col=omit.col,...)
+    age2radial(x,from=from,to=to,t0=t0,sigdig=sigdig,
+               transformation=transformation,
+               show.numbers=show.numbers,pch=pch,levels=levels,
+               clabel=clabel,bg=bg,col=col,markers=markers,k=k,
+               exterr=exterr,i2i=i2i,alpha=alpha,hide=hide,
+               omit=omit,omit.col=omit.col,...)
 }
 #' @rdname radialplot
 #' @export
-radialplot.KCa <- function(x,from=NA,to=NA,t0=NA,
+radialplot.KCa <- function(x,from=NA,to=NA,t0=NA,sigdig=2,
                            transformation='log',show.numbers=FALSE,
                            pch=21,levels=NA,clabel="",
                            bg=c("yellow","red"),col='black',
                            markers=NULL,k=0,exterr=TRUE,i2i=FALSE,
                            alpha=0.05,hide=NULL,omit=NULL,
                            omit.col=NA,...){
-    radialplot_helper(x,from=from,to=to,t0=t0,
-                      transformation=transformation,
-                      show.numbers=show.numbers,pch=pch,levels=levels,
-                      clabel=clabel,bg=bg,col=col,markers=markers,k=k,
-                      exterr=exterr,i2i=i2i,alpha=alpha,hide=hide,
-                      omit=omit,omit.col=omit.col,...)
+    age2radial(x,from=from,to=to,t0=t0,sigdig=sigdig,
+               transformation=transformation,
+               show.numbers=show.numbers,pch=pch,levels=levels,
+               clabel=clabel,bg=bg,col=col,markers=markers,k=k,
+               exterr=exterr,i2i=i2i,alpha=alpha,hide=hide,
+               omit=omit,omit.col=omit.col,...)
 }
 #' @rdname radialplot
 #' @export
-radialplot.UThHe <- function(x,from=NA,to=NA,t0=NA,
+radialplot.UThHe <- function(x,from=NA,to=NA,t0=NA,sigdig=2,
                              transformation='log',show.numbers=FALSE,
                              pch=21,levels=NA,clabel="",
                              bg=c("yellow","red"),col='black',
                              markers=NULL,k=0,alpha=0.05,
                              hide=NULL,omit=NULL,omit.col=NA,...){
-    radialplot_helper(x,from=from,to=to,t0=t0,
-                      transformation=transformation,
-                      show.numbers=show.numbers,pch=pch,levels=levels,
-                      clabel=clabel,bg=bg,col=col,markers=markers,k=k,
-                      exterr=FALSE,alpha=alpha,hide=hide,omit=omit,
-                      omit.col=omit.col,...)
+    age2radial(x,from=from,to=to,t0=t0,sigdig=sigdig,
+               transformation=transformation,
+               show.numbers=show.numbers,pch=pch,levels=levels,
+               clabel=clabel,bg=bg,col=col,markers=markers,k=k,
+               exterr=FALSE,alpha=alpha,hide=hide,omit=omit,
+               omit.col=omit.col,...)
 }
 #' @rdname radialplot
 #' @export
-radialplot.ReOs <- function(x,from=NA,to=NA,t0=NA,
+radialplot.ReOs <- function(x,from=NA,to=NA,t0=NA,sigdig=2,
                             transformation='log',show.numbers=FALSE,
                             pch=21,levels=NA,clabel="",
                             bg=c("yellow","red"),col='black',
                             markers=NULL,k=0,exterr=TRUE,i2i=TRUE,
                             alpha=0.05,hide=NULL,omit=NULL,
                             omit.col=NA,...){
-    radialplot_helper(x,from=from,to=to,t0=t0,
-                      transformation=transformation,
-                      show.numbers=show.numbers,pch=pch,levels=levels,
-                      clabel=clabel,bg=bg,col=col,markers=markers,k=k,
-                      exterr=exterr,i2i=i2i,alpha=alpha,hide=hide,
-                      omit=omit,omit.col=omit.col,...)
+    age2radial(x,from=from,to=to,t0=t0,sigdig=sigdig,
+               transformation=transformation,
+               show.numbers=show.numbers,pch=pch,levels=levels,
+               clabel=clabel,bg=bg,col=col,markers=markers,k=k,
+               exterr=exterr,i2i=i2i,alpha=alpha,hide=hide,
+               omit=omit,omit.col=omit.col,...)
 }
 #' @rdname radialplot
 #' @export
-radialplot.SmNd <- function(x,from=NA,to=NA,t0=NA,
+radialplot.SmNd <- function(x,from=NA,to=NA,t0=NA,sigdig=2,
                             transformation='log',show.numbers=FALSE,
                             pch=21,levels=NA,clabel="",
                             bg=c("yellow","red"),col='black',
                             markers=NULL,k=0,exterr=TRUE,i2i=TRUE,
                             alpha=0.05,hide=NULL,omit=NULL,
                             omit.col=NA,...){
-    radialplot_helper(x,from=from,to=to,t0=t0,
-                      transformation=transformation,
-                      show.numbers=show.numbers,pch=pch,levels=levels,
-                      clabel=clabel,bg=bg,col=col,markers=markers,k=k,
-                      exterr=exterr,i2i=i2i,alpha=alpha,hide=hide,
-                      omit=omit,omit.col=omit.col,...)
+    age2radial(x,from=from,to=to,t0=t0,sigdig=sigdig,
+               transformation=transformation,
+               show.numbers=show.numbers,pch=pch,levels=levels,
+               clabel=clabel,bg=bg,col=col,markers=markers,k=k,
+               exterr=exterr,i2i=i2i,alpha=alpha,hide=hide,
+               omit=omit,omit.col=omit.col,...)
 }
 #' @rdname radialplot
 #' @export
-radialplot.RbSr <- function(x,from=NA,to=NA,t0=NA,
+radialplot.RbSr <- function(x,from=NA,to=NA,t0=NA,sigdig=2,
                             transformation='log',show.numbers=FALSE,
                             pch=21,levels=NA,clabel="",
                             bg=c("yellow","red"),col='black',
                             markers=NULL,k=0,exterr=TRUE,i2i=TRUE,
                             alpha=0.05,hide=NULL,omit=NULL,
                             omit.col=NA,...){
-    radialplot_helper(x,from=from,to=to,t0=t0,
-                      transformation=transformation,
-                      show.numbers=show.numbers,pch=pch,levels=levels,
-                      clabel=clabel,bg=bg,col=col,markers=markers,k=k,
-                      exterr=exterr,i2i=i2i,alpha=alpha,hide=hide,
-                      omit=omit,omit.col=omit.col,...)
+    age2radial(x,from=from,to=to,t0=t0,sigdig=sigdig,
+               transformation=transformation,
+               show.numbers=show.numbers,pch=pch,levels=levels,
+               clabel=clabel,bg=bg,col=col,markers=markers,k=k,
+               exterr=exterr,i2i=i2i,alpha=alpha,hide=hide,
+               omit=omit,omit.col=omit.col,...)
 }
 #' @rdname radialplot
 #' @export
-radialplot.LuHf <- function(x,from=NA,to=NA,t0=NA,
+radialplot.LuHf <- function(x,from=NA,to=NA,t0=NA,sigdig=2,
                             transformation='log',show.numbers=FALSE,
                             pch=21,levels=NA,clabel="",
                             bg=c("yellow","red"),col='black',
                             markers=NULL,k=0,exterr=TRUE,i2i=TRUE,
                             alpha=0.05,hide=NULL,omit=NULL,
                             omit.col=NA,...){
-    radialplot_helper(x,from=from,to=to,t0=t0,
-                      transformation=transformation,
-                      show.numbers=show.numbers,pch=pch,levels=levels,
-                      clabel=clabel,bg=bg,col=col,markers=markers,k=k,
-                      exterr=exterr,i2i=i2i,alpha=alpha,hide=hide,
-                      omit=omit,omit.col=omit.col,...)
+    age2radial(x,from=from,to=to,t0=t0,sigdig=sigdig,
+               transformation=transformation,
+               show.numbers=show.numbers,pch=pch,levels=levels,
+               clabel=clabel,bg=bg,col=col,markers=markers,k=k,
+               exterr=exterr,i2i=i2i,alpha=alpha,hide=hide,
+               omit=omit,omit.col=omit.col,...)
 }
 #' @param detritus detrital \eqn{^{230}}Th correction (only applicable
 #'     when \code{x$format == 1} or \code{2}).
@@ -393,55 +393,73 @@ radialplot.LuHf <- function(x,from=NA,to=NA,t0=NA,
 #' \eqn{^{234}}U/\eqn{^{238}}U-ratios in the detritus.
 #' @rdname radialplot
 #' @export
-radialplot.ThU <- function(x,from=NA,to=NA,t0=NA,
+radialplot.ThU <- function(x,from=NA,to=NA,t0=NA,sigdig=2,
                            transformation='log',show.numbers=FALSE,
                            pch=21,levels=NA,clabel="",
                            bg=c("yellow","red"),col='black',markers=NULL,
                            k=0,i2i=TRUE,alpha=0.05,detritus=0,
                            hide=NULL,omit=NULL,omit.col=NA,...){
-    radialplot_helper(x,from=from,to=to,t0=t0,
-                      transformation=transformation,
-                      show.numbers=show.numbers,pch=pch,levels=levels,
-                      clabel=clabel,bg=bg,col=col,markers=markers,k=k,
-                      exterr=FALSE,i2i=i2i,alpha=alpha,units='ka',
-                      detritus=detritus,hide=hide,omit=omit,omit.col=omit.col,...)
-}
-radialplot_helper <- function(x,from=NA,to=NA,t0=NA,transformation='log',
-                              type=4,cutoff.76=1100,cutoff.disc=c(-15,5),
-                              show.numbers=FALSE,pch=21,levels=NA,
-                              clabel="",bg=c("yellow","red"),col='black',
-                              markers=NULL,k=0,exterr=TRUE,i2i=FALSE,
-                              common.Pb=0,alpha=0.05,units='Ma',detritus=0,
-                              hide=NULL,omit=NULL,omit.col=NA,...){
-    x2calc <- clear(x,hide,omit)
-    peaks <- peakfit(x2calc,k=k,exterr=exterr,i2i=i2i,type=type,
-                     cutoff.76=cutoff.76,cutoff.disc=cutoff.disc,
-                     common.Pb=common.Pb,detritus=detritus)
-    markers <- c(markers,peaks$peaks['t',])
-    age2radial(x,from=from,to=to,t0=t0,transformation=transformation,
-               type=type,cutoff.76=cutoff.76,cutoff.disc=cutoff.disc,
+    age2radial(x,from=from,to=to,t0=t0,sigdig=sigdig,
+               transformation=transformation,
                show.numbers=show.numbers,pch=pch,levels=levels,
-               clabel=clabel,bg=bg,col=col,markers=markers,i2i=i2i,
-               alpha=alpha,units=units,detritus=detritus,hide=hide,
-               omit=omit,omit.col=omit.col,common.Pb=common.Pb,...)
+               clabel=clabel,bg=bg,col=col,markers=markers,k=k,
+               exterr=FALSE,i2i=i2i,alpha=alpha,units='ka',
+               detritus=detritus,hide=hide,omit=omit,omit.col=omit.col,...)
+}
+age2radial <- function(x,from=NA,to=NA,t0=NA,transformation='log',
+                       type=4,cutoff.76=1100,cutoff.disc=c(-15,5),
+                       show.numbers=FALSE,pch=21,levels=NA,sigdig=2,
+                       clabel="",bg=c("yellow","red"),col='black',
+                       markers=NULL,k=0,exterr=TRUE,i2i=FALSE,
+                       common.Pb=0,alpha=0.05,units='Ma',detritus=0,
+                       hide=NULL,omit=NULL,omit.col=NA,...){
+    x2calc <- clear(x,hide,omit)
+    peaks <- peakfit(x2calc,k=k,exterr=exterr,sigdig=sigdig,
+                     i2i=i2i,type=type,cutoff.76=cutoff.76,
+                     cutoff.disc=cutoff.disc,common.Pb=common.Pb,
+                     detritus=detritus)
+    markers <- c(markers,peaks$peaks['t',])
+    tt <- get.ages(x2calc,type=type,cutoff.76=cutoff.76,cutoff.disc=cutoff.disc,
+                   i2i=i2i,detritus=detritus,common.Pb=common.Pb)
+    radial_helper(tt,from=from,to=to,t0=t0,
+                  transformation=transformation,
+                  show.numbers=show.numbers,pch=pch,levels=levels,
+                  clabel=clabel,bg=bg,col=col,markers=markers,
+                  alpha=alpha,units=units,hide=hide,omit=omit,
+                  omit.col=omit.col,...)
+    fit <- central(tt,alpha=alpha)
+    if (exterr){
+        fit$age[1:2] <- add.exterr(x2calc,tt=fit$age[1],st=fit$age[2],
+                                   cutoff.76=cutoff.76,type=type)
+        fit$age[3] <- fit$age[2]*nfact(alpha)
+    }
+    graphics::title(radial.title(fit,sigdig=sigdig,alpha=alpha,
+                                 units=units,ntit=get.ntit(tt[,1])))
     if (!is.null(peaks$legend))
         graphics::legend('bottomleft',legend=peaks$legend,bty='n')
 }
 
-age2radial <- function(x,from=NA,to=NA,t0=NA,transformation='log',
-                       type=4,cutoff.76=1100,cutoff.disc=c(-15,5),
-                       show.numbers=FALSE,pch=21,levels=NA,clabel="",
-                       bg=c("yellow","red"),col='black',markers=NULL,
-                       k=0,i2i=FALSE,alpha=0.05,units='MA',detritus=0,
-                       hide=NULL,omit=NULL,omit.col=NA,common.Pb=0,...){
-    tt <- get.ages(x,type=type,cutoff.76=cutoff.76,cutoff.disc=cutoff.disc,
-                   i2i=i2i,detritus=detritus,common.Pb=common.Pb)
-    radialplot.default(tt,from=from,to=to,t0=t0,
-                       transformation=transformation,
-                       show.numbers=show.numbers,pch=pch,
-                       levels=levels,clabel=clabel,bg=bg,col=col,
-                       markers=markers,alpha=alpha,units=units,
-                       hide=hide,omit=omit,omit.col=omit.col,...)
+radial_helper <- function(x,from=NA,to=NA,t0=NA,transformation='log',
+                          type=4,cutoff.76=1100,cutoff.disc=c(-15,5),
+                          show.numbers=FALSE,pch=21,levels=NA,clabel="",
+                          bg=c("yellow","red"),col='black',markers=NULL,
+                          k=0,i2i=FALSE,alpha=0.05,units='MA',detritus=0,
+                          hide=NULL,omit=NULL,omit.col=NA,common.Pb=0,...){
+    x <- x[,c(1,2),drop=FALSE]
+    ns <- nrow(x)
+    calcit <- (1:ns)%ni%c(hide,omit)
+    plotit <- (1:ns)%ni%hide
+    x2calc <- clear(x,hide,omit)
+    x2plot <- clear(x,hide)
+    X <- x2zs(x,t0=t0,from=from,to=to,transformation=transformation)
+    pcol <- set.ellipse.colours(ns=ns,levels=levels,col=bg,hide=hide,
+                                omit=omit,omit.col=omit.col)
+    tcol <- rep(col,ns)
+    tcol[omit] <- 'grey'
+    radial.plot(X,show.numbers=show.numbers,pch=pch,
+                levels=levels[plotit],clabel=clabel,markers=markers,
+                bg=pcol[plotit],col=tcol[plotit],sn=(1:ns)[plotit],...)
+    colourbar(z=levels[calcit],col=bg,clabel=clabel)    
 }
 
 radial.plot <- function(x,zeta=0,rhoD=0,asprat=3/4,
@@ -777,9 +795,8 @@ iatt <- function(z,zeta,rhoD){
 }
 
 # this would be much easier in unicode but that doesn't render in PDF:
-radial.title <- function(x,sigdig=2,alpha=0.05,units='',
-                         ntit=paste0('n=',length(x)),...){
-    fit <- central(x,alpha=alpha)
+radial.title <- function(fit,sigdig=2,alpha=0.05,units='',
+                         ntit=paste0('n=',fit$df+2),...){
     rounded.age <- roundit(fit$age[1],fit$age[2:3],sigdig=sigdig)
     rounded.disp <- roundit(100*fit$disp[1],100*fit$disp[2:3],sigdig=sigdig)
     line1 <- substitute('central age ='~a%+-%b~'|'~c~d~'('*n*')',
