@@ -70,7 +70,7 @@ model3regression <- function(xyz,type='york'){
 LL.isochron <- function(w,xyz,type='york'){
     if (identical(type,'york'))
         out <- LL.york(w,xyz)
-    else
+    else if (identical(type,'titterington'))
         out <- LL.titterington(w,xyz)
     out
 }
@@ -125,6 +125,8 @@ LL.titterington <- function(w,xyz){
     }
     out
 }
+LL.ludwig <- function(w,xyz){
+}
 
 augment_york_errors <- function(xy,w){
     out <- xy
